import { ChangeDetectorRef, Component, EventEmitter, Input, Output } from '@angular/core';
import { ToastrService } from 'ngx-toastr';
import { MyPLModel, PLModel } from 'src/app/shared/model/pl.model';
import { MyPmsGroupAssessment1Model, PmsGroupAssessment1Model } from 'src/app/shared/model/pms-group-assessment1.model';
import { PmsGroupAssessmentService } from 'src/app/shared/services/pms-group-assessment.service';
@Component({
  selector: 'app-edit-evaluation-grouping',
  templateUrl: './edit-evaluation-grouping.component.html',
  styleUrls: ['./edit-evaluation-grouping.component.scss']
})
export class EditEvaluationGroupingComponent {
  @Output() sendOnEdit: EventEmitter<boolean> = new EventEmitter<boolean>();
  @Input() pl: PLModel = new MyPLModel()
  currentPage = 1
  page = Array.from({ length: 1 }, (_, i) => i + 1);
  search = ""
  currentModal: 'add' | 'edit' | 'delete' | 'deleteGroup' = "add"

  pmsGroupAssessment: { loading: boolean, select: PmsGroupAssessment1Model, dataList: { check: boolean, data: PmsGroupAssessment1Model }[] } = { loading: false, select: new MyPmsGroupAssessment1Model(), dataList: [] }

  numDataListChecked = 0
  isDataListChecked = false
  isDataListCheckedAll = false
  constructor(private toastr: ToastrService,
    private pmsGroupAssessmentService: PmsGroupAssessmentService,
    private cdr: ChangeDetectorRef
  ) { }
  ngOnInit(): void {
    this.getPmsGroupAssessmentBy_plId()
  }

  getPmsGroupAssessmentBy_plId() {
    this.pmsGroupAssessment.loading = true
    this.pmsGroupAssessmentService.getBy_plId(this.pl.plId).subscribe({
      next: response => {
        this.pmsGroupAssessment.dataList = response.pmsGroupAssessment1List.map(x => ({ check: false, data: new MyPmsGroupAssessment1Model(x) }))
        this.pmsGroupAssessment.loading = false
        this.isDataListCheckedAll = false
        this.dataListCheckAll()
        this.searchChange();
        this.cdr.detectChanges();
      }, error: error => {
        this.pmsGroupAssessment.loading = false
        this.cdr.detectChanges()
      }
    });
  }
  pmsGroupAssessmentListFilter() {
    return this.pmsGroupAssessment.dataList.filter(x => {
      const data = x.data
      const match = data.pmsTopic.pmsTopicId.toLowerCase().includes(this.search.toLowerCase()) || data.pmsTopic.tdesc.toLowerCase().includes(this.search.toLowerCase())
      return match;
    });
  }
  selectPmsGroupAssessment(data: PmsGroupAssessment1Model) {
    this.pmsGroupAssessment.select = new MyPmsGroupAssessment1Model(data)
  }

  searchChange() {
    this.currentPage = 1
    this.page = Array.from({ length: Math.ceil(this.pmsGroupAssessmentListFilter().length / 10) }, (_, i) => i + 1)
    this.dataListCheck();
    this.cdr.detectChanges()
  }
  dataListCheckAll() {
    const selectAll = this.isDataListCheckedAll;
    this.pmsGroupAssessmentListFilter().forEach(x => x.check = selectAll);
    this.dataListCheck();
  }
  dataListCheck() {
    const dataCheck = this.pmsGroupAssessmentListFilter();
    this.isDataListCheckedAll = dataCheck.length ? dataCheck.every(x => x.check) : false;
    this.numDataListChecked = this.pmsGroupAssessment.dataList.filter(x => x.check).length
    this.isDataListChecked = Boolean(this.numDataListChecked)
  }

  onBack() {
    this.sendOnEdit.emit(false);
  }

}
